GetFeeForMessage class

Get Fee For Message

A codec for getFeeForMessage JSON RPC methods.

Inheritance

Constructors

GetFeeForMessage(String message, {GetFeeForMessageConfig? config})
Creates a codec for getFeeForMessage JSON RPC methods.

Properties

config Serializable?
finalinherited
hashCode int
The hash code for this object.
no setterinherited
method String
The JSON RPC method name,
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
values List<Object?>
finalinherited

Methods

decoder(Map<String, dynamic> value) JsonRpcResponseContext<u64?>
Decodes the result property of a successful JSON RPC response.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
params([Commitment? commitment]) Object?
Returns the JSON RPC request's params property value.
inherited
request([Commitment? commitment]) JsonRpcRequest
Creates a JsonRpcRequest to invoke method with params. The commitment level is provided as a default value to all methods that query bank state.
inherited
response(Map<String, dynamic> json) JsonRpcResponse<JsonRpcResponseContext<u64?>>
Parses the json RPC response and returns the result.
inherited
toString() String
A string representation of this object.
inherited
valueDecoder(u64? value) u64?
Decodes the value property of a successful JSON RPC response-context.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited