GetInflationReward class
Get Inflation Reward
A codec for getInflationReward JSON RPC methods.
- Inheritance
-
- Object
- JsonRpcMethod<
List, List< InflationReward?> > - GetInflationReward
Constructors
-
GetInflationReward(List<
String> addresses, {GetInflationRewardConfig? config}) -
Creates a codec for
getInflationRewardJSON RPC methods. -
GetInflationReward.map(Iterable<
Pubkey> addresses, {GetInflationRewardConfig? config}) -
factory
Properties
Methods
-
decoder(
List value) → List< InflationReward?> -
Decodes the
resultproperty of a successful JSON RPC response.inherited -
itemDecoder(
Map< String, dynamic> ? item) → InflationReward? - Decodes an item in the JSON RPC List response.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
params(
[Commitment? commitment]) → Object? -
Returns the JSON RPC request's
paramsproperty value.inherited -
request(
[Commitment? commitment]) → JsonRpcRequest -
Creates a JsonRpcRequest to invoke method with params. The
commitmentlevel is provided as a default value to all methods that query bank state.inherited -
response(
Map< String, dynamic> json) → JsonRpcResponse<List< InflationReward?> > -
Parses the
jsonRPC response and returns the result.inherited -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited