LogsSubscribe class
Logs Subscribe
A method handler for logsSubscribe.
- Inheritance
-
- Object
- JsonRpcMethod<
SubscriptionId, SubscriptionId> - LogsSubscribe
Constructors
-
LogsSubscribe(LogsFilter<
Object> filter, {LogsSubscribeConfig? config}) -
Creates a method handler for
logsSubscribe.
Properties
Methods
-
decoder(
SubscriptionId value) → SubscriptionId -
Decodes the
resultproperty of a successful JSON RPC response.inherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
params(
[Commitment? commitment]) → Object? -
Returns the JSON RPC request's
paramsproperty value.inherited -
request(
[Commitment? commitment]) → JsonRpcRequest -
Creates a JsonRpcRequest to invoke method with params. The
commitmentlevel is provided as a default value to all methods that query bank state.inherited -
response(
Map< String, dynamic> json) → JsonRpcResponse<SubscriptionId> -
Parses the
jsonRPC response and returns the result.inherited -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited