GetBlockCommitment class
Get Block Commitment
A codec for getBlockCommitment JSON RPC methods.
- Inheritance
-
- Object
- JsonRpcMethod<
Map< String, dynamic> , BlockCommitment> - GetBlockCommitment
Constructors
- GetBlockCommitment(u64 block)
-
Creates a codec for
getBlockCommitmentJSON RPC methods.
Properties
Methods
-
decoder(
Map< String, dynamic> value) → BlockCommitment -
Decodes the
resultproperty of a successful JSON RPC response.override -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
params(
[Commitment? commitment]) → Object? -
Returns the JSON RPC request's
paramsproperty value.inherited -
request(
[Commitment? commitment]) → JsonRpcRequest -
Creates a JsonRpcRequest to invoke method with params. The
commitmentlevel is provided as a default value to all methods that query bank state.inherited -
response(
Map< String, dynamic> json) → JsonRpcResponse<BlockCommitment> -
Parses the
jsonRPC response and returns the result.inherited -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited